.. SPDX-FileCopyrightText: 2020-2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm package
================

Modules
-------

.. toctree::
   :maxdepth: 1

   main/oc_ocdm.abstract_entity
   main/oc_ocdm.abstract_set
   main/oc_ocdm.decorators
   main/oc_ocdm.reader
   main/oc_ocdm.storer

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   oc_ocdm.counter_handler
   oc_ocdm.graph
   oc_ocdm.metadata
   oc_ocdm.prov
   oc_ocdm.support
